# Python Connector for Salesforce #

Python Connector for Salesforce is a connectivity solution for accessing
Salesforce from Python applications to read and update data. It fully
implements the Python DB API 2.0 specification. The connector is distributed
as a wheel package for Windows, macOS, and Linux.
 
Standard SQL syntax
 
The connector fully supports the ANSI SQL standard and lets you execute
SQL statements against your Salesforce data just like you would normally
work with relational databases. Simple queries are directly converted
to Salesforce API calls and executed on the Salesforce side.

## Using the connector ##

To retrieve data from a database:
 
Import the module.
 
```
import devart.salesforce
```
 
Connect to a database using the `connect()` module method and obtain a `connection` object:
 
If you're using basic authentication:
```
my_connection = devart.salesforce.connect(
    Authentication="Basic",
    Host="your_org_url",
    UserId="your_username",
    UserPassword="your_password",
    SecurityToken="your_token"
)
```
If you're using OAuth 2.0 authentication and have a refresh token:
```
my_connection = devart.salesforce.connect(
    Authentication="OAuth",
    Host="your_org_url",
    RefreshToken="your_refresh_token"
)
```
If you're using OAuth 2.0 authentication and don't have a refresh token:
```
dict = salesforce.signin(Host="your_org_url")
my_connection = devart.salesforce.connect(
    Authentication="OAuth",
    Host="your_org_url",
    UserId="your_username",
    Password="your_password",
    SecurityToken="your_token",
    RefreshToken=dict["Refresh Token"]
)
```
 
Create a `cursor` object using the `cursor()` connection method.
 
```
my_cursor = my_connection.cursor()
```
 
Execute the SQL statement using the `execute()` cursor method.
 
```
my_cursor.execute("SELECT * FROM employees")
```
 
Retrieve the result set using one of the `fetch*()` cursor methods.
 
```
for row in my_cursor.fetchall(): 
    print(row)
```

## What's new ##

Python Connector for Salesforce 1.0
 
* Initial release of Python Connector for Salesforce
* Added support for Windows 32-bit and 64-bit
* Added support for Windows Server 32-bit and 64-bit
* Added support for macOS 64-bit and ARM (Apple M1 and M2)
* Added support for Linux 64-bit
